#Copyright © 2016 RTE Réseau de transport d’électricité

require(testthat)
require(antaresRead)
require(plyr)

test_check("antaresRead")
